# -*- coding: utf-8 -*-
"""Grader feature module for OpenJudge Studio.

This module provides the Grader evaluation feature, allowing users to
evaluate LLM responses using built-in graders.
"""

from features.grader.feature import GraderFeature

__all__ = ["GraderFeature"]
