# -*- coding: utf-8 -*-
"""Auto Arena feature module for OpenJudge Studio.

This module provides the UI for running automated model/agent evaluations,
which automatically evaluates AI models or agents without labeled data.
"""

from features.auto_arena.feature import AutoArenaFeature

__all__ = ["AutoArenaFeature"]
